@@ -7,6 +7,7 @@ from docutils.utils import new_document, relative_path
 from myst_parser.sphinx_parser import MystParser
 
 from . import __version__
+from .vitepress import VitePressBuilder
 
 
 def process_doctree(app, doctree, docname):
@@ -85,6 +86,8 @@ def setup(app):
     app.connect("doctree-resolved", process_doctree)
     app.add_directive("mdinclude", MdInclude)
 
+    app.add_builder(VitePressBuilder)
+
     return {
         "version": __version__,
         "parallel_read_safe": True,
